import type { Handler, HandlerContext, HandlerResponse } from '@netlify/functions';
import { fetch, Request } from 'undici';
export type RouteParams<T extends string> = T extends `${infer Prev}/*/${infer Rest}` ? RouteParams<Prev> & {
    wild: string;
} & RouteParams<Rest> : T extends `${string}:${infer P}/${infer Rest}` ? {
    [K in P]?: string;
} & RouteParams<Rest> : T extends `${string}:${infer P}?/${infer Rest}` ? {
    [K in P]?: string;
} & RouteParams<Rest> : T extends `${string}:${infer P}/${infer Rest}` ? {
    [K in P]: string;
} & RouteParams<Rest> : T extends `${string}:${infer P}?` ? {
    [K in P]?: string;
} : T extends `${string}:${infer P}.${string}` ? {
    [K in P]: string;
} : T extends `${string}:${infer P}` ? {
    [K in P]: string;
} : T extends `${string}*` ? {
    wild: string;
} : object;
type HTTPMethod = 'DELETE' | 'GET' | 'HEAD' | 'OPTIONS' | 'PATCH' | 'POST' | 'PUT';
export type RequestHandler<T extends string> = (event: {
    cookies: Record<string, string>;
    fetch: typeof fetch;
    getClientAddress: () => string | undefined;
    params: RouteParams<T>;
    platform: {
        context: HandlerContext;
    };
    request: Request;
    url: URL;
}) => Promise<HandlerResponse>;
declare const match: <T extends string>(method: HTTPMethod | HTTPMethod[], path: T, handler: RequestHandler<T>) => Handler;
export declare const DELETE: <T extends string>(path: T, handler: RequestHandler<T>) => Handler;
export declare const GET: <T extends string>(path: T, handler: RequestHandler<T>) => Handler;
export declare const HEAD: <T extends string>(path: T, handler: RequestHandler<T>) => Handler;
export declare const OPTIONS: <T extends string>(path: T, handler: RequestHandler<T>) => Handler;
export declare const PATCH: <T extends string>(path: T, handler: RequestHandler<T>) => Handler;
export declare const POST: <T extends string>(path: T, handler: RequestHandler<T>) => Handler;
export declare const PUT: <T extends string>(path: T, handler: RequestHandler<T>) => Handler;
export default match;
